tiled.structures.xarray.DataArrayMacroStructure
===============================================

.. currentmodule:: tiled.structures.xarray

.. autoclass:: DataArrayMacroStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataArrayMacroStructure.__init__
      ~DataArrayMacroStructure.from_json
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataArrayMacroStructure.resizable
   
   